.. _contributing:


***************
Contributing
***************

There are many ways in which contributions can be made - the first and foremost being *using staircase and giving feedback*.

Bug reports, feature requests and ideas can be submitted via the `Github issue tracker <https://github.com/venaturum/staircase/issues>`_.

Additionally, bug fixes. enhancements, and improvements to the code and documentation are also appreciated and can be done via pull requests.
Take a look at the current issues and if there is one you would like to work on please leave a comment to that effect.

See this `beginner's guide to contributing <https://github.com/firstcontributions/first-contributions>`_, or `Pandas' guide to contributing <https://pandas.pydata.org/pandas-docs/stable/development/contributing.html>`_, to learn more about the process.


.. _contributing.developer_guide:

Developer guide
==================

COMING SOON
